@@ -18,7 +18,7 @@
 #include "ui_aboutdialog.h"
 
 AboutDialog::AboutDialog(QWidget *parent) :
-	QMainWindow(parent),
+        QMainWindow(parent),
 	m_ui(new Ui::AboutDialog)
 {
 	m_ui->setupUi(this);
@@ -31,7 +31,7 @@ AboutDialog::~AboutDialog()
 
 void AboutDialog::changeEvent(QEvent *e)
 {
-	QMainWindow::changeEvent(e);
+        QWidget::changeEvent(e);
 	switch (e->type()) {
 	case QEvent::LanguageChange:
 		m_ui->retranslateUi(this);
