@@ -25,7 +25,7 @@ namespace Ui {
 	class AddTorrentDialog;
 }
 
-class AddTorrentDialog : public QMainWindow {
+class AddTorrentDialog : public QMainWindow { //QMainWindow {
 	Q_OBJECT
 public:
 	AddTorrentDialog(QWidget *parent, BtConnection* con);
